@@ -43,11 +43,6 @@ try:
 except ImportError:
     import json
 
-try:
-    from vtfunc import TableFunction
-except ImportError:
-    pass
-
 from peewee import *
 from peewee import EnclosedClause
 from peewee import Entity
@@ -700,7 +695,8 @@ def ClosureTable(model_class, foreign_key=None):
             query = (model_class
                      .select(model_class, cls.depth.alias('depth'))
                      .join(cls, on=(primary_key == cls.id))
-                     .where(cls.root == node))
+                     .where(cls.root == node)
+                     .naive())
             if depth is not None:
                 query = query.where(cls.depth == depth)
             elif not include_node:
@@ -712,7 +708,8 @@ def ClosureTable(model_class, foreign_key=None):
             query = (model_class
                      .select(model_class, cls.depth.alias('depth'))
                      .join(cls, on=(primary_key == cls.root))
-                     .where(cls.id == node))
+                     .where(cls.id == node)
+                     .naive())
             if depth:
                 query = query.where(cls.depth == depth)
             elif not include_node:
@@ -953,20 +950,6 @@ class SqliteExtDatabase(SqliteDatabase):
         return super(SqliteExtDatabase, self).create_index(
             model_class, field_name, unique)
 
-    def granular_transaction(self, lock_type='deferred'):
-        assert lock_type.lower() in ('deferred', 'immediate', 'exclusive')
-        return granular_transaction(self, lock_type)
-
-
-class granular_transaction(transaction):
-    def __init__(self, db, lock_type='deferred'):
-        self.db = db
-        self.conn = self.db.get_conn()
-        self.lock_type = lock_type
-
-    def _begin(self):
-        self.db.begin(self.lock_type)
-
 
 OP.MATCH = 'match'
 SqliteExtDatabase.register_ops({
